==> keyclic_sdk_api-1.28.9.tar.gz: lib/model/success_login_credentials.dart <==
part of keyclic_sdk_api.api;

class SuccessLoginCredentials {
  String id = null;

  String login = null;

  List<String> roles = [];

  List<SuccessLoginCredentialsAdministratorOf> administratorOf = [];

  List<SuccessLoginCredentialsMemberOf> memberOf = [];

  SuccessLoginCredentials();

  @override
  String toString() {
    return 'SuccessLoginCredentials[id=$id, login=$login, roles=$roles, administratorOf=$administratorOf, memberOf=$memberOf, ]';
  }

  SuccessLoginCredentials.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    id = json['id'];
    login = json['login'];
    roles = (json['roles'] as List)?.map((item) => item as String)?.toList();
    administratorOf = SuccessLoginCredentialsAdministratorOf.listFromJson(
        json['administratorOf']);
    memberOf = SuccessLoginCredentialsMemberOf.listFromJson(json['memberOf']);
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id,
      'login': login,
      'roles': roles,
      'administratorOf': administratorOf,
      'memberOf': memberOf
    };
  }

  static List<SuccessLoginCredentials> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<SuccessLoginCredentials>()
        : json
            .map((value) => new SuccessLoginCredentials.fromJson(value))
            .toList();
  }

  static Map<String, SuccessLoginCredentials> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, SuccessLoginCredentials>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new SuccessLoginCredentials.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/success_login_credentials.dart <==
part of keyclic_sdk_api.api;

class SuccessLoginCredentials {
  String id = null;

  String login = null;

  List<String> roles = [];

  List<SuccessLoginCredentialsAdministratorOf> administratorOf = [];

  List<SuccessLoginCredentialsMemberOf> memberOf = [];

  SuccessLoginCredentials({
    this.id,
    this.login,
    this.roles,
    this.administratorOf,
    this.memberOf,
  });

  @override
  String toString() {
    return 'SuccessLoginCredentials[id=$id, login=$login, roles=$roles, administratorOf=$administratorOf, memberOf=$memberOf, ]';
  }

  SuccessLoginCredentials.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    id = json['id'];
    login = json['login'];
    roles = (json['roles'] as List)?.map((item) => item as String)?.toList();
    administratorOf = SuccessLoginCredentialsAdministratorOf.listFromJson(
        json['administratorOf']);
    memberOf = SuccessLoginCredentialsMemberOf.listFromJson(json['memberOf']);
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id,
      'login': login,
      'roles': roles,
      'administratorOf': administratorOf,
      'memberOf': memberOf,
    };
  }

  static List<SuccessLoginCredentials> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<SuccessLoginCredentials>()
        : json
            .map((value) => new SuccessLoginCredentials.fromJson(value))
            .toList();
  }

  static Map<String, SuccessLoginCredentials> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, SuccessLoginCredentials>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new SuccessLoginCredentials.fromJson(value));
    }
    return map;
  }
}
